@@ -1,7 +1,3 @@
-#include <Python.h>
-#include <AppKit/AppKit.h>
-#include "pyobjc-api.h"
-
 static PyObject* 
 call_NSBitmapImageRep_getTIFFCompressionTypes_count_(
 	PyObject* method, PyObject* self, PyObject* arguments)
@@ -11,7 +7,7 @@ call_NSBitmapImageRep_getTIFFCompressionTypes_count_(
 	PyObject* result;
 	struct objc_super super;
 	NSTIFFCompression* list;
-	int numTypes;
+	NSInteger numTypes;
 
 	if  (!PyArg_ParseTuple(arguments, "OO", &a1, &a2)) {
 		return NULL;
@@ -31,7 +27,7 @@ call_NSBitmapImageRep_getTIFFCompressionTypes_count_(
 			PyObjCSelector_GetClass(method),
 			PyObjCClass_GetClass(self));
 
-		(void)objc_msgSendSuper(&super,
+		((void(*)(struct objc_super*, SEL, NSTIFFCompression**, NSInteger*))objc_msgSendSuper)(&super,
 				PyObjCSelector_GetSelector(method),
 				&list, &numTypes);
 	PyObjC_HANDLER
@@ -154,7 +150,7 @@ call_NSBitmapImageRep_initWithBitmap(PyObject* method,
 {
 	PyObject* result;
 	PyObject* maybeNone;
-	char *dataPlanes[5];
+	unsigned char *dataPlanes[5];
 	int garbage;
 	int width, height;
 	int bps, spp;
@@ -166,7 +162,7 @@ call_NSBitmapImageRep_initWithBitmap(PyObject* method,
 	struct objc_super super;
 
 	// check for five well defined read buffers in data planes argument
-	if (!PyArg_ParseTuple(arguments, "(z#z#z#z#z#)iiiibbsii",
+	if (!PyArg_ParseTuple(arguments, "("Py_ARG_BYTES"#"Py_ARG_BYTES"#"Py_ARG_BYTES"#"Py_ARG_BYTES"#"Py_ARG_BYTES"#)iiiibbsii",
 		&dataPlanes[0], &garbage,
 		&dataPlanes[1], &garbage,
 		&dataPlanes[2], &garbage,
@@ -218,7 +214,7 @@ call_NSBitmapImageRep_initWithBitmap(PyObject* method,
 			PyObjCSelector_GetClass(method),
 			PyObjCObject_GetObject(self));
     
-		newImageRep = objc_msgSendSuper(&super,
+		newImageRep = ((id(*)(struct objc_super*, SEL, unsigned char**, NSInteger, NSInteger, NSInteger, NSInteger, BOOL, BOOL, id, NSInteger, NSInteger))objc_msgSendSuper)(&super,
 				PyObjCSelector_GetSelector(method),
 				dataPlanes, width, height, bps, spp, 
 				hasAlpha, isPlanar, colorSpaceNameString, 
@@ -262,9 +258,9 @@ call_NSBitmapImageRep_getBitmapDataPlanes_(PyObject* method,
 			PyObjCSelector_GetClass(method),
 			PyObjCObject_GetObject(self));
     
-		(void)objc_msgSendSuper(&super, 
+		((void(*)(struct objc_super*, SEL, unsigned char***))objc_msgSendSuper)(&super, 
 			PyObjCSelector_GetSelector(method),
-			&dataPlanes);
+			(unsigned char***)&dataPlanes);
 
 		bytesPerPlane = [
 			(NSBitmapImageRep*)PyObjCObject_GetObject(self) 
@@ -282,7 +278,16 @@ call_NSBitmapImageRep_getBitmapDataPlanes_(PyObject* method,
 	if (result != NULL) {
 		for(i=0; i<5; i++) {
 			if (dataPlanes[i]) {
+#if PY_VERSION_HEX <= 0x02069900
 				PyObject* buffer = PyBuffer_FromReadWriteMemory(dataPlanes[i], bytesPerPlane);
+#else
+				Py_buffer info;
+				if (PyBuffer_FillInfo(&info, NULL, dataPlanes[i], bytesPerPlane, 1, PyBUF_FULL) < 0) {
+					return NULL;
+				}
+				PyObject* buffer = PyMemoryView_FromBuffer(&info);
+#endif
+
 				if ( (!buffer) || PyErr_Occurred()) {
 					Py_DECREF(result);
 					result = NULL;
@@ -335,8 +340,27 @@ call_NSBitmapImageRep_bitmapData(PyObject* method,
 		return NULL;
 	}
 
+#if  PY_VERSION_HEX <= 0x02069900 
 	result = PyBuffer_FromReadWriteMemory(bitmapData, bytesPerPlane);
-	if (PyErr_Occurred()) {
+#else
+	/* A memory view requires that the backing store implements the buffer
+	 * interface, therefore create a mutable bytes object to do that for us.
+	 */
+	Py_buffer info;
+	NSMutableData* data = [[NSMutableData alloc] initWithBytesNoCopy:bitmapData length: bytesPerPlane freeWhenDone:NO];
+	PyObject* bytesBuf = PyObjC_ObjCToPython("@", &data);
+	[data release];
+	if (bytesBuf == NULL) {
+		return NULL;
+	}
+
+	if (PyBuffer_FillInfo(&info, bytesBuf, bitmapData, bytesPerPlane, 0, PyBUF_FULL) < 0) {
+		return NULL;
+	}
+	result = PyMemoryView_FromBuffer(&info);
+
+#endif
+	if (result == NULL) {
 		if (result) {
 			Py_DECREF(result);
 		}
@@ -349,26 +373,19 @@ call_NSBitmapImageRep_bitmapData(PyObject* method,
 
 
 
-static PyMethodDef mod_methods[] = {
-	{ 0, 0, 0, 0 } /* sentinel */
-};
-
-void init_nsbitmap(void);
-void init_nsbitmap(void)
+static int setup_nsbitmap(PyObject* m __attribute__((__unused__)))
 {
-	PyObject* m = Py_InitModule4("_nsbitmap", mod_methods, "", NULL,
-			PYTHON_API_VERSION);
-
-	PyObjC_ImportAPI(m);
-
 	Class class_NSBitmapImageRep = objc_lookUpClass("NSBitmapImageRep");
+	if (class_NSBitmapImageRep == NULL) {
+		return 0;
+	}
 
 	if (PyObjC_RegisterMethodMapping(class_NSBitmapImageRep, 
 		@selector(getTIFFCompressionTypes:count:),
 		call_NSBitmapImageRep_getTIFFCompressionTypes_count_,
 		PyObjCUnsupportedMethod_IMP) < 0 ) {
 
-		return;
+		return -1;
 	}
 
 	if (PyObjC_RegisterMethodMapping(
@@ -377,7 +394,7 @@ void init_nsbitmap(void)
 			call_NSBitmapImageRep_initWithBitmap,
 			PyObjCUnsupportedMethod_IMP) < 0) {
 
-		return;
+		return -1;
 	}
 
 	if (PyObjC_RegisterMethodMapping(
@@ -386,7 +403,7 @@ void init_nsbitmap(void)
 			call_NSBitmapImageRep_getBitmapDataPlanes_,
 			PyObjCUnsupportedMethod_IMP) < 0) {
 
-		return;
+		return -1;
 	}
 
 	if (PyObjC_RegisterMethodMapping(
@@ -395,6 +412,8 @@ void init_nsbitmap(void)
 			call_NSBitmapImageRep_bitmapData,
 			PyObjCUnsupportedMethod_IMP) < 0) {
 
-		return;
+		return -1;
 	}
+
+	return 0;
 }
