@@ -4,9 +4,6 @@ from Foundation import *
 
 class TestNSClassDescription (TestCase):
     def testConstants(self):
-        self.failUnless(isinstance(NSClassDescriptionNeededForClassNotification, unicode))
-
-
-
+        self.assertIsInstance(NSClassDescriptionNeededForClassNotification, unicode)
 if __name__ == "__main__":
     main()
