@@ -7,13 +7,13 @@ from Foundation import *
 
 class TestNSProcessInfo (TestCase):
     def testConstants(self):
-        self.assertEquals(NSWindowsNTOperatingSystem, 1)
-        self.assertEquals(NSWindows95OperatingSystem, 2)
-        self.assertEquals(NSSolarisOperatingSystem, 3)
-        self.assertEquals(NSHPUXOperatingSystem, 4)
-        self.assertEquals(NSMACHOperatingSystem, 5)
-        self.assertEquals(NSSunOSOperatingSystem, 6)
-        self.assertEquals(NSOSF1OperatingSystem, 7)
+        self.assertEqual(NSWindowsNTOperatingSystem, 1)
+        self.assertEqual(NSWindows95OperatingSystem, 2)
+        self.assertEqual(NSSolarisOperatingSystem, 3)
+        self.assertEqual(NSHPUXOperatingSystem, 4)
+        self.assertEqual(NSMACHOperatingSystem, 5)
+        self.assertEqual(NSSunOSOperatingSystem, 6)
+        self.assertEqual(NSOSF1OperatingSystem, 7)
 
     def testNSDisabledSuddenTermination(self):
         # annoyingly we cannot easily test if this has an effect, but
