@@ -11,11 +11,18 @@ class ThreadingTest (TestCase):
     def setUp(self):
         # Set a very small check interval, this will make it more likely
         # that the interpreter crashes when threading is done incorrectly.
-        self._int = sys.getcheckinterval()
-        sys.setcheckinterval(1)
+        if sys.version_info[:2] >= (3, 2):
+            self._int = sys.getswitchinterval()
+            sys.setswitchinterval(0.0000001)
+        else:
+            self._int = sys.getcheckinterval()
+            sys.setcheckinterval(1)
 
     def tearDown(self):
-        sys.setcheckinterval(self._int)
+        if sys.version_info[:2] >= (3, 2):
+            sys.setswitchinterval(self._int)
+        else:
+            sys.setcheckinterval(self._int)
 
     def testNSObjectString(self):
 
@@ -37,7 +44,7 @@ class ThreadingTest (TestCase):
                 'run:', myObj, u"hello world")
 
         time.sleep(2)
-        self.assertEquals(myObj.storage[0], u"hello world")
+        self.assertEqual(myObj.storage[0], u"hello world")
 
     def testNSObject(self):
 
@@ -58,7 +65,7 @@ class ThreadingTest (TestCase):
             lst2.append(i*2)
 
         time.sleep(2)
-        self.assertEquals(lst, range(100))
+        self.assertEqual(lst, range(100))
 
     def testPyObject(self):
         import os
@@ -87,7 +94,7 @@ class ThreadingTest (TestCase):
                 lst2.append(i*2)
 
             time.sleep(2)
-            self.assertEquals(lst, range(100))
+            self.assertEqual(lst, range(100))
 
         finally:
             os.dup2(dupped, 2)
